@@ -1,7 +1,7 @@
 /* -*- mode: c; c-basic-offset: 4; indent-tabs-mode: nil -*- */
 /*
- * Copyright 2000, 2002, 2003, 2007, 2008 by the Massachusetts Institute of Technology.
- * All Rights Reserved.
+ * Copyright 2000, 2002, 2003, 2007, 2008 by the Massachusetts Institute of
+ * Technology.  All Rights Reserved.
  *
  * Export of this software from the United States of America may
  *   require a specific license from the United States Government.
@@ -21,7 +21,6 @@
  * M.I.T. makes no representations about the suitability of
  * this software for any purpose.  It is provided "as is" without express
  * or implied warranty.
- *
  */
 /*
  * Copyright 1993 by OpenVision Technologies, Inc.
@@ -476,15 +475,14 @@ make_ap_req_v1(context, ctx, cred, k_cred, ad_context,
          * For DCE RPC, do not encapsulate the AP-REQ in the
          * typical GSS wrapping.
          */
-        token->length = ap_req.length;
-        token->value = ap_req.data;
-
-        ap_req.data = NULL; /* don't double free */
+        code = data_to_gss(&ap_req, token);
+        if (code)
+            goto cleanup;
     } else {
         /* allocate space for the token */
         tlen = g_token_size((gss_OID) mech_type, ap_req.length);
 
-        if ((t = (unsigned char *) xmalloc(tlen)) == NULL) {
+        if ((t = (unsigned char *) gssalloc_malloc(tlen)) == NULL) {
             code = ENOMEM;
             goto cleanup;
         }
@@ -611,10 +609,11 @@ kg_new_connection(
         ctx->krb_times.endtime = now + time_req;
     }
 
-    if ((code = kg_duplicate_name(context, cred->name, 0, &ctx->here)))
+    if ((code = kg_duplicate_name(context, cred->name, &ctx->here)))
         goto cleanup;
 
-    if ((code = kg_duplicate_name(context, (krb5_gss_name_t)target_name, 0, &ctx->there)))
+    if ((code = kg_duplicate_name(context, (krb5_gss_name_t)target_name,
+                                  &ctx->there)))
         goto cleanup;
 
     code = get_credentials(context, cred, ctx->there, now,
@@ -692,12 +691,6 @@ kg_new_connection(
     if (actual_mech_type)
         *actual_mech_type = mech_type;
 
-    /* At this point, the context is constructed and valid; intern it. */
-    if (! kg_save_ctx_id((gss_ctx_id_t) ctx)) {
-        code = G_VALIDATE_FAILED;
-        goto cleanup;
-    }
-
     /* return successfully */
 
     *context_handle = (gss_ctx_id_t) ctx;
@@ -721,9 +714,9 @@ cleanup:
         if (ctx_free->auth_context)
             krb5_auth_con_free(context, ctx_free->auth_context);
         if (ctx_free->here)
-            kg_release_name(context, 0, &ctx_free->here);
+            kg_release_name(context, &ctx_free->here);
         if (ctx_free->there)
-            kg_release_name(context, 0, &ctx_free->there);
+            kg_release_name(context, &ctx_free->there);
         if (ctx_free->subkey)
             krb5_k_free_key(context, ctx_free->subkey);
         xfree(ctx_free);
@@ -771,13 +764,6 @@ mutual_auth(
     if (code)
         goto fail;
 
-    /* validate the context handle */
-    /*SUPPRESS 29*/
-    if (! kg_validate_ctx_id(*context_handle)) {
-        *minor_status = (OM_uint32) G_VALIDATE_FAILED;
-        return(GSS_S_NO_CONTEXT);
-    }
-
     ctx = (krb5_gss_ctx_id_t) *context_handle;
 
     /* make sure the context is non-established, and that certain
@@ -893,8 +879,9 @@ mutual_auth(
         if (code)
             goto fail;
 
-        output_token->value = outbuf.data;
-        output_token->length = outbuf.length;
+        code = data_to_gss(&outbuf, output_token);
+        if (code)
+            goto fail;
     }
 
     /* set established */
@@ -944,6 +931,7 @@ krb5_gss_init_sec_context_ext(
     krb5_gss_ctx_ext_t exts)
 {
     krb5_context context;
+    gss_cred_id_t defcred = GSS_C_NO_CREDENTIAL;
     krb5_gss_cred_id_t cred;
     krb5_error_code kerr;
     OM_uint32 major_status;
@@ -972,43 +960,28 @@ krb5_gss_init_sec_context_ext(
     if (actual_mech_type)
         *actual_mech_type = NULL;
 
-    /* verify that the target_name is valid and usable */
-
-    if (! kg_validate_name(target_name)) {
-        *minor_status = (OM_uint32) G_VALIDATE_FAILED;
-        save_error_info(*minor_status, context);
-        if (*context_handle == GSS_C_NO_CONTEXT)
-            krb5_free_context(context);
-        return(GSS_S_CALL_BAD_STRUCTURE|GSS_S_BAD_NAME);
-    }
-
     /* verify the credential, or use the default */
     /*SUPPRESS 29*/
     if (claimant_cred_handle == GSS_C_NO_CREDENTIAL) {
-        major_status = kg_get_defcred(minor_status, (gss_cred_id_t *)&cred);
+        major_status = kg_get_defcred(minor_status, &defcred);
         if (major_status && GSS_ERROR(major_status)) {
             if (*context_handle == GSS_C_NO_CONTEXT)
                 krb5_free_context(context);
             return(major_status);
         }
-    } else {
-        major_status = krb5_gss_validate_cred(minor_status, claimant_cred_handle);
-        if (GSS_ERROR(major_status)) {
-            save_error_info(*minor_status, context);
-            if (*context_handle == GSS_C_NO_CONTEXT)
-                krb5_free_context(context);
-            return(major_status);
-        }
-        cred = (krb5_gss_cred_id_t) claimant_cred_handle;
+        claimant_cred_handle = defcred;
     }
-    kerr = k5_mutex_lock(&cred->lock);
-    if (kerr) {
-        if (claimant_cred_handle == GSS_C_NO_CREDENTIAL)
-            krb5_gss_release_cred(minor_status, (gss_cred_id_t *)&cred);
-        krb5_free_context(context);
-        *minor_status = kerr;
-        return GSS_S_FAILURE;
+
+    major_status = kg_cred_resolve(minor_status, context, claimant_cred_handle,
+                                   target_name);
+    if (GSS_ERROR(major_status)) {
+        save_error_info(*minor_status, context);
+        krb5_gss_release_cred(&tmp_min_stat, &defcred);
+        if (*context_handle == GSS_C_NO_CONTEXT)
+            krb5_free_context(context);
+        return(major_status);
     }
+    cred = (krb5_gss_cred_id_t)claimant_cred_handle;
 
     /* verify the mech_type */
 
@@ -1022,8 +995,7 @@ krb5_gss_init_sec_context_ext(
         mech_type = (gss_OID) gss_mech_iakerb;
     } else {
         k5_mutex_unlock(&cred->lock);
-        if (claimant_cred_handle == GSS_C_NO_CREDENTIAL)
-            krb5_gss_release_cred(minor_status, (gss_cred_id_t *)&cred);
+        krb5_gss_release_cred(minor_status, &defcred);
         *minor_status = 0;
         if (*context_handle == GSS_C_NO_CONTEXT)
             krb5_free_context(context);
@@ -1060,9 +1032,7 @@ krb5_gss_init_sec_context_ext(
            too.  */
     }
 
-    if (claimant_cred_handle == GSS_C_NO_CREDENTIAL)
-        krb5_gss_release_cred(&tmp_min_stat, (gss_cred_id_t *)&cred);
-
+    krb5_gss_release_cred(&tmp_min_stat, &defcred);
     return(major_status);
 }
 
@@ -1120,7 +1090,7 @@ krb5int_gss_use_kdc_context(OM_uint32 *minor_status,
 }
 #endif
 
-OM_uint32
+OM_uint32 KRB5_CALLCONV
 krb5_gss_init_sec_context(minor_status, claimant_cred_handle,
                           context_handle, target_name, mech_type,
                           req_flags, time_req, input_chan_bindings,
@@ -1159,4 +1129,3 @@ krb5_gss_init_sec_context(minor_status, claimant_cred_handle,
                                          time_rec,
                                          &exts);
 }
-
